==> huaweicloudsdkservicestage-3.0.52-py2.py3-none-any.whl: huaweicloudsdkservicestage/v2/model/build_info.py <==
# coding: utf-8

import re
import six





class BuildInfo:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'parameters': 'BuildInfoParameters'
    }

    attribute_map = {
        'id': 'id',
        'parameters': 'parameters'
    }

    def __init__(self, id=None, parameters=None):
        """BuildInfo - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._parameters = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if parameters is not None:
            self.parameters = parameters

    @property
    def id(self):
        """Gets the id of this BuildInfo.

        构建ID，查看构建列表获取。

        :return: The id of this BuildInfo.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BuildInfo.

        构建ID，查看构建列表获取。

        :param id: The id of this BuildInfo.
        :type: str
        """
        self._id = id

    @property
    def parameters(self):
        """Gets the parameters of this BuildInfo.


        :return: The parameters of this BuildInfo.
        :rtype: BuildInfoParameters
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this BuildInfo.


        :param parameters: The parameters of this BuildInfo.
        :type: BuildInfoParameters
        """
        self._parameters = parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BuildInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkservicestage-3.0.54-py2.py3-none-any.whl: huaweicloudsdkservicestage/v2/model/build_info.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BuildInfo:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'parameters': 'BuildInfoParameters'
    }

    attribute_map = {
        'id': 'id',
        'parameters': 'parameters'
    }

    def __init__(self, id=None, parameters=None):
        """BuildInfo - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._parameters = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if parameters is not None:
            self.parameters = parameters

    @property
    def id(self):
        """Gets the id of this BuildInfo.

        构建ID，查看构建列表获取。

        :return: The id of this BuildInfo.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BuildInfo.

        构建ID，查看构建列表获取。

        :param id: The id of this BuildInfo.
        :type: str
        """
        self._id = id

    @property
    def parameters(self):
        """Gets the parameters of this BuildInfo.


        :return: The parameters of this BuildInfo.
        :rtype: BuildInfoParameters
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this BuildInfo.


        :param parameters: The parameters of this BuildInfo.
        :type: BuildInfoParameters
        """
        self._parameters = parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BuildInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
